FromPRS

Struct FromPRS 

pub struct FromPRS;
Origin from a ProdRuleSet perspective: Origin<VarId, FromPRS>, where VarId identifies a children nonterminal in the processed ProdRuleSet:

and associates it with a node (VarId, usize) of the original RuleTreeSet rules after normalization (but keeping the * and + ops).

The alternatives of the ProdRuleSet store their own (VarId, usize) links to the original nodes because it’s easier than to track the data when they’re moved around.