pub enum Terminate {
None,
Abort,
Conclude,
}Expand description
Codes returned by the check_abort_request(…) method of the listener (via the wrapper pass-through).
Variants
None
Normal behaviour: continues parsing the text
Abort
Irrecoverable error: stops parsing, calls the listener abort method, and returns an error
Conclude
Stops parsing, calls the listener exit method, and returns an Ok