Module parsergen

Module parsergen 

Structs

ParserGen
ParserTables
Tables and parameters used to create a Parser. This type is used as a return object from the parser generator, when the Parser must be created dynamically; for example, in tests or in situations where the grammar isn’t known in advance. In those situations, the ParserTables object must live as long as the parser it generates.

Enums

NTValue
Determines which nonterminals have a value, so a dedicated type and field in contexts:

Statics

DEFAULT_LISTENER_NAME

Type Aliases

SpanNbr