pub enum NTValue {
None,
Parents,
Default,
SetIds(Vec<VarId>),
SetNames(Vec<String>),
}Expand description
Determines which nonterminals have a value, so a dedicated type and field in contexts:
None: No nonterminal has a valueParents: Only the top nonterminal parents have a valueDefault: The top nonterminal parents and the children of(<L> )+*have a valueSetIds(Vec<VarId>): The nonterminals that have a value is set explicitly by IDSetNames(Vec<String>): The nonterminals that have a value is set explicitly by name. The names “<default>” and “<parents>” can be used to set all the nonterminals of the corresponding class. Individual nonterminals can be preceded by a “-” to indicate they don’t hold a value.
Variants
None
No nonterminal has a value
Parents
Only the top nonterminal parents have a value
Default
The top nonterminal parents and the children of (<L> )+* have a value
SetIds(Vec<VarId>)
The set of nonterminals that have a value is set explicitly by ID
SetNames(Vec<String>)
The set of nonterminals that have a value is set explicitly by name. Individual names preceded by a “-” don’t have a value.
Implementations
Sourceimpl NTValue
impl NTValue
Sourcepub const DEFAULT: &str = "<default>"
pub const DEFAULT: &str = "<default>"
Only the top nonterminal parents have a value (can be used in NTValue::SetNames)
Sourcepub const PARENTS: &str = "<parents>"
pub const PARENTS: &str = "<parents>"
The top nonterminal parents and the children of (<L> )+* have a value (can be used in NTValue::SetNames)
pub fn is_none(&self) -> bool
pub fn is_parents(&self) -> bool
pub fn is_default(&self) -> bool
pub fn is_ids(&self) -> bool
pub fn is_names(&self) -> bool