ParserGenOptions

Struct ParserGenOptions 

pub struct ParserGenOptions {
    pub nt_value: NTValue,
    pub include_alts: bool,
    pub headers: Vec<String>,
    pub used_libs: StructLibs,
    pub gen_wrapper: bool,
    pub gen_span_params: bool,
    pub gen_token_enums: bool,
    pub lib_crate: LexigramCrate,
    pub indent: usize,
    pub types_indent: usize,
    pub listener_indent: usize,
}

Fields

nt_value: NTValueinclude_alts: boolheaders: Vec<String>used_libs: StructLibsgen_wrapper: bool

generates the wrapper source code

gen_span_params: bool

generates code to give the location of nonterminals and tokens as extra parameters of listener methods

gen_token_enums: boollib_crate: LexigramCrateindent: usize

source code indentation of the wrapper, in number of space characters

types_indent: usize

source code indentation of the template for the user types

listener_indent: usize

source code indentation of the template for the listener implementation