pub enum DiffResult {
Equal,
Mismatch {
line_num: usize,
line1: String,
line2: String,
},
}Expand description
Result of a line-by-line comparison of two strings. Reports either that everything was equal or the first line mismatch.
Variants
Equal
The two strings are equal line by line (EOL may differ in nature: Linux vs Windows)
Mismatch
The two strings differ, starting at line line_num (differing lines included)