macro_rules! filename {
() => { ... };
}Expand description
Expands to the file name in which it was invoked, like file!,
but transforms Windows path separators to /, so that they match on a
Linux system (useful when generated text is verified in unit tests).