Structs
Enums
- Call
- Action calls to the wrapper with the method ListenerWrapper::switch. The wrapper translates the action accordingly to the current nonterminal and alternative; for example, by calling the appropriate listener callback.
- OpCode
- Parser
Error - Code of the error that occurred during the parsing, returned by the parse_stream(…) method of the parser.
- Symbol
- Terminate
- Codes returned by the check_abort_request(…) method of the listener (via the wrapper pass-through).